# -*- coding: utf-8 -*-
# Copyright 2015-TODAY LasLabs Inc.
# License MIT (https://opensource.org/licenses/MIT).

from carepoint import Carepoint
from sqlalchemy import (Column,
                        Integer,
                        String,
                        Boolean,
                        )


class FdbNdc(Carepoint.BASE):
    __tablename__ = 'fdrndc'
    __dbname__ = 'cph'

    ndc = Column(String, primary_key=True)
    id = Column(Integer)
    lblrid = Column(String)
    gcn_seqno = Column(Integer)
    ps = Column(Integer)
    df = Column(Integer)
    ad = Column(String)
    ln = Column(String)
    bn = Column(String)
    pndc = Column(Integer)
    repndc = Column(Integer)
    ndcfi = Column(Integer)
    daddnc = Column(String)
    dupdc = Column(String)
    desi = Column(String)
    desdtec = Column(Integer)
    desi2 = Column(String)
    des2dtec = Column(Integer)
    dea = Column(Integer)
    cl = Column(String)
    gpi = Column(Integer)
    hosp = Column(Integer)
    innov = Column(Integer)
    ipi = Column(Integer)
    mini = Column(Integer)
    maint = Column(Integer)
    obc = Column(String)
    obsdtec = Column(String)
    ppi = Column(Integer)
    stpk = Column(Integer)
    repack = Column(Integer)
    top200 = Column(Integer)
    ud = Column(Integer)
    csp = Column(Integer)
    color = Column(String)
    flavor = Column(String)
    shape = Column(String)
    ndl_gdge = Column(Integer)
    ndl_lngth = Column(Integer)
    syr_cpcty = Column(Integer)
    shlf_pck = Column(Integer)
    shipper = Column(Integer)
    skey = Column(String)
    hcfa_fda = Column(String)
    hcfa_unit = Column(String)
    hcfa_ps = Column(Integer)
    hcfa_appc = Column(Integer)
    hcfa_mrkc = Column(Integer)
    hcfa_trmc = Column(Integer)
    hcfa_typ = Column(Integer)
    hcfa_desc1 = Column(Integer)
    hcfa_desi1 = Column(Integer)
    uu = Column(Integer)
    pd = Column(String)
    ln25 = Column(String)
    ln25i = Column(Integer)
    gpidc = Column(Integer)
    bbdc = Column(Integer)
    home = Column(Integer)
    inpcki = Column(Integer)
    outpcki = Column(Integer)
    obc_exp = Column(String)
    ps_equiv = Column(Integer)
    plblr = Column(Integer)
    hcpc = Column(String)
    top50gen = Column(Integer)
    obc3 = Column(String)
    gmi = Column(Integer)
    gni = Column(Integer)
    gsi = Column(Integer)
    gti = Column(Integer)
    ndcgi1 = Column(Integer)
    user_gcdf = Column(String)
    user_str = Column(String)
    real_product_yn = Column(Boolean)
    no_update_yn = Column(Boolean)
    no_prc_update_yn = Column(Boolean)
    user_product_yn = Column(Integer)
    cpname_short = Column(String)
    status_cn = Column(String)
    update_yn = Column(Boolean)
    active_yn = Column(Boolean)
    ln60 = Column(String)
